@@ -1,5 +1,5 @@
 from datetime import datetime
-from typing import Any, List, Optional
+from typing import List, Optional
 from uuid import UUID
 
 from pydantic import parse_obj_as, root_validator, validator
@@ -8,12 +8,9 @@ from alpaca.broker.models.documents import AccountDocument
 from ..enums import (
     AgreementType,
     ClearingBroker,
-    DTBPCheck,
     EmploymentStatus,
     FundingSource,
-    PDTCheck,
     TaxIdType,
-    TradeConfirmationEmail,
     VisaType,
 )
 from alpaca.trading.enums import AccountStatus
@@ -320,26 +317,3 @@ class TradeAccount(BaseTradeAccount):
     last_daytrade_count: Optional[int]
     last_buying_power: Optional[str]
     clearing_broker: Optional[ClearingBroker]
-
-
-class TradeAccountConfiguration(BaseModel):
-    """
-    Represents configuration options for a TradeAccount.
-
-    Attributes:
-        dtbp_check (DTBPCheck): Day Trade Buying Power Check. Controls Day Trading Margin Call (DTMC) checks.
-        fractional_trading (bool): If true, account is able to participate in fractional trading
-        max_margin_multiplier (str): A number between 1-4 that represents your max margin multiplier
-        no_shorting (bool): If true then Account becomes long-only mode.
-        pdt_check (PDTCheck): Controls Pattern Day Trader (PDT) checks.
-        suspend_trade (bool): If true Account becomes unable to submit new orders
-        trade_confirm_email (TradeConfirmationEmail): Controls whether Trade confirmation emails are sent.
-    """
-
-    dtbp_check: DTBPCheck
-    fractional_trading: bool
-    max_margin_multiplier: str
-    no_shorting: bool
-    pdt_check: PDTCheck
-    suspend_trade: bool
-    trade_confirm_email: TradeConfirmationEmail
